@@ -1,6 +1,6 @@
 /* -*- Mode: C -*-
 
-  $Id: gpgmeplug.c,v 1.2 2002/11/28 18:33:01 marcus Exp $
+  $Id: gpgmeplug.c,v 1.2.2.2 2002/12/05 08:36:38 werner Exp $
 
   GPGMEPLUG - an GPGME based cryptography plug-in following
               the common CRYPTPLUG specification.
@@ -335,6 +335,16 @@ bool hasFeature( Feature flag )
 
 const char* libVersion(){ return config.libVersion; }
 
+/* Return the current interface version.  This is a simple way for a
+   user to check whether all required fucntions are available.  If
+   MIN_VERSION is not NULL the lowest supported version of the
+   interface is returned in addition. */
+int interfaceVersion (int *min_version) 
+{
+  if (min_version)
+    *min_version = 0;
+  return 1;
+} 
 
 const char* bugURL(){ return config.bugURL; }
 
